@@ -16,7 +16,7 @@ import gi
 gi.require_version('GstBase', '1.0')
 
 from gi.repository import Gst, GObject, GstBase
-Gst.init(None)
+Gst.init_python()
 
 #
 # Simple Identity element created entirely in python
